import {FC, useState} from 'react'
import * as Yup from 'yup'
import {useFormik} from 'formik'
import {isNotEmpty, QUERIES, toAbsoluteUrl} from '../../../../../../../_metronic/helpers'
import {initialPerson, initialPersonRole, initialPersonRoleType, Person, PersonRole, PersonRoleType, Position} from '../../core/_models'
import clsx from 'clsx'
import { useListView } from '../person/ListViewProviderPerson'
import {getPersonRoleTypes, getPersons, getUsers, savePerson, savePosition} from '../../core/_requests'
import {useQueryResponse} from '../../core/QueryResponseProviderPerson'
import {useQuery} from 'react-query'
import { CREATE_PERSON_ROLE } from '../../../../AppUtils'
import {useQueryClient} from 'react-query'
import {ListLoading} from '../../components/loading/ListLoading'
import { PositionSelectionCell } from '../../table/columns/position/PositionSelectionCell'


type Props = {
  isPositionLoading: boolean
  position: Position
}

const PersonAddModalForm: FC<Props> = ({position, isPositionLoading}) => {
  const {setItemIdForUpdate} = useListView()
  const {refetch} = useQueryResponse()
  const queryClient = useQueryClient()
  const {query} = useQueryResponse()

  const {
    isLoading,
    data: persons,
    error,
  } = useQuery(
    `${QUERIES.PERSONS_LIST}-persons-${query}`,
    () => {
      return getPersons(query, 0)
    },
    {
      cacheTime: 0,
      enabled: true,
      onError: (err) => {
        console.error(err)
      },
    }
  )
  

  const [personToAdd] = useState<Person>({
    id: undefined
  })

  const cancel = (withRefresh?: boolean) => {
    if (withRefresh) {
      refetch()
    }
    setItemIdForUpdate(undefined)
  }

  const formik = useFormik({
    initialValues: personToAdd,
    onSubmit: async (values, {setSubmitting}) => {
      console.log(values)
      if(position.persons){
        position.persons?.push(values)
      }else{
        position.persons = [values]
      }
      console.log(position)
      setSubmitting(true)
      try {
 
          await savePosition(position)
          
      } catch (ex) {
        console.error(ex)
      } finally {
        setSubmitting(true)
        cancel(true)
        queryClient.invalidateQueries([`${QUERIES.POSITIONS_LIST}-${query}`])
      }
    },
  })


  return (
    <>
      <form id='kt_modal_add_user_form' className='form' onSubmit={formik.handleSubmit} noValidate>
        {/* begin::Scroll */}
        <div
          className='d-flex flex-column scroll-y me-n7 pe-7'
          id='kt_modal_add_user_scroll'
          data-kt-scroll='true'
          data-kt-scroll-activate='{default: false, lg: true}'
          data-kt-scroll-max-height='auto'
          data-kt-scroll-dependencies='#kt_modal_add_user_header'
          data-kt-scroll-wrappers='#kt_modal_add_user_scroll'
          data-kt-scroll-offset='300px'
        >
          {/* begin::Input group */}
          <div className='fv-row mb-7'>
            {/* begin::Label */}
            <label className='required fw-bold fs-6 mb-2'>Person</label>
            {/* end::Label */}

            {/* begin::Input */}
            {persons?.data && persons?.data?.filter(x => !position.persons?.map(person => Number(person.id)).find(id => id === Number(x.id))).map( person=> {
                  return(
                <div className='fv-row' key={person.id}>
                  {/* begin::Radio */}
                  <div className='form-check form-check-custom form-check-solid'>
                    {/* begin::Input */}
                    <input
                      className='form-check-input me-3'
                      {...formik.getFieldProps('id')}
                      name='id'
                      type='radio'
                      value={String(person.id)}
                      id='kt_modal_update_role_option_0'
                      disabled={formik.isSubmitting || isLoading}
                    />
                    {/* end::Input */}
                  
                    {/* begin::Label */}
                    <label className='form-check-label' htmlFor='kt_modal_update_role_option_0'>
                      <div className='fw-bolder text-gray-800'>{[person.forename, " ", person.surname]}</div>

                    </label>
                    {/* end::Label */}
                    
                  </div>
                  {/* end::Radio */}
                  <div className='fv-row mb-7'> </div>


                </div>
                
                )
              } )}
            {/* end::Input */}
          </div>
          {/* end::Input group */}
        </div>
        {/* end::Scroll */}

        {/* begin::Actions */}
        <div className='text-center pt-15'>
          <button
            type='reset'
            onClick={() => cancel()}
            className='btn btn-light me-3'
            data-kt-users-modal-action='cancel'
            disabled={formik.isSubmitting || isPositionLoading}
          >
            Discard
          </button>

          <button
            type='submit'
            className='btn btn-primary'
            data-kt-users-modal-action='submit'
            disabled={isPositionLoading || formik.isSubmitting || !formik.isValid || !formik.touched}
          >
            <span className='indicator-label'>Submit</span>
            {(formik.isSubmitting || isPositionLoading) && (
              <span className='indicator-progress'>
                Please wait...{' '}
                <span className='spinner-border spinner-border-sm align-middle ms-2'></span>
              </span>
            )}
          </button>
        </div>
        {/* end::Actions */}
      </form>
      {(formik.isSubmitting || isPositionLoading) && <ListLoading />}
    </>
  )
}

export {PersonAddModalForm}
